@@ -1,6 +1,4 @@
-import pytz
 from django.db import models
-from django.conf import settings
 
 import recurrence as recur
 from recurrence import managers, choices
